# -*- coding: UTF-8 -*-

from os.path import dirname
import sys

import setuptools
from distutils.core import setup

# http://stackoverflow.com/a/7071358/735926
import re
VERSIONFILE='firapria/__init__.py'
verstrline = open(VERSIONFILE, 'rt').read()
VSRE = r'^__version__\s+=\s+[\'"]([^\'"]+)[\'"]'
mo = re.search(VSRE, verstrline, re.M)
if mo:
    verstr = mo.group(1)
else:
    raise RuntimeError("Unable to find version string in %s." % VERSIONFILE)

setup(
    name='firapria',
    version=verstr,
    author='Baptiste Fontaine',
    author_email='b@ptistefontaine.fr',
    packages=['firapria'],
    url='https://github.com/bfontaine/firapria',
    license=open('LICENSE', 'r').read(),
    description='Get pollution indices for IDF (France)',
    long_description=open('README.rst', 'r').read(),
    install_requires=[
        'colorama >= 0.2.7',
        'beautifulsoup >= 4.3.2',
    ],
    classifiers=[
        'Environment :: Console',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
    ],
    entry_points={
        'console_scripts':[
            'firapria = firapria.cli:main'
        ]
    },
)



# -*- coding: UTF-8 -*-

"""
Command-line interface
"""

import sys
import argparse
from firapria.pollution import PollutionFetcher

from colorama import init, Fore
init(autoreset=True)


def print_version_and_exit():
    from firapria import __version__
    print("firapria v%s" % __version__)
    sys.exit(0)


def colorize_indices(indices, max_value):
    def colorize(i):
        c = Fore.RESET

        if i >= max_value:
            c = Fore.YELLOW
        elif i > 0.75 * max_value:
            c = Fore.RED
        elif i > 0.5 * max_value:
            c = Fore.MAGENTA
        elif i > 0.25 * max_value:
            c = Fore.GREEN
        else:
            c = Fore.WHITE

    return map(colorize, indices)


def print_pollution():
    p = PollutionFetcher()
    print """Pollution:
    Yesterday: %s
    Today: %s
    Tomorrow: %s""" % tuple(colorize_indices(p.indices(), max_val=100))


def main():
    parser = argparse.ArgumentParser(
        description='Get pollution indices for Paris'
    )
    parser.add_argument('--pollution', dest='pollution', short='-p',
                        default=True, help='print pollution info')
    parser.add_argument('--version', action='store_true')
    if args.version:
        print_version_and_exit()

    if args.pollution:
        print_pollution()



# -*- coding: UTF-8 -*-

"""
Get pollution info in Île-de-France from http://www.airparif.asso.fr/
"""

from bs4 import BeautifulSoup
from urllib import urlopen


class PollutionFetcher():

    EU, FR = 'eu', 'fr'  # indices types

    def __init__(self):
        self.doc = None
        self.fetch_from = 'http://www.airparif.asso.fr/'

    def __fetch(self):
        self.doc = BeautifulSoup(urlopen(self.fetch_from))

    def indices(self, _type=EU):
        """
        Return a list of 3 integers representing indices for yesterday, today
        and tomorrow, using the given type (EU or FR).
        """
        if self.doc is None:
            self.__fetch()
        div = self.doc.select('#home_indices_%s' % _type)
        if not div:
            return None
        divs = div[0].select('.indices_data .selected')
        return map(lambda d: int(d.text), divs)
